@@ -27,15 +27,12 @@
 
 #include "iconthemeconfig.h"
 
-#include <XdgDesktopFile>
-#include <XdgIcon>
 #include <LXQt/Settings>
 #include <QStringList>
+#include <QStringBuilder>
 #include <QIcon>
-#include <QDebug>
 
-
-IconThemeConfig::IconThemeConfig(LxQt::Settings* settings, QWidget* parent):
+IconThemeConfig::IconThemeConfig(LXQt::Settings* settings, QWidget* parent):
     QWidget(parent),
     m_settings(settings)
 {
@@ -45,25 +42,31 @@ IconThemeConfig::IconThemeConfig(LxQt::Settings* settings, QWidget* parent):
     initControls();
     connect(iconThemeList, SIGNAL(itemClicked(QTreeWidgetItem*,int)),
             this, SLOT(iconThemeSelected(QTreeWidgetItem*,int)));
-
-    connect(LxQt::Settings::globalSettings(), SIGNAL(settingsChanged()),
-            this, SLOT(update()));
 }
 
 
 void IconThemeConfig::initIconsThemes()
 {
     QStringList processed;
-    QStringList baseDirs = QIcon::themeSearchPaths();
+    const QStringList baseDirs = QIcon::themeSearchPaths();
+    static const QStringList iconNames = QStringList()
+                    << QStringLiteral("document-open")
+                    << QStringLiteral("document-new")
+                    << QStringLiteral("edit-undo")
+                    << QStringLiteral("media-playback-start");
 
-    foreach (QString baseDirName, baseDirs)
+    const int iconNamesN = iconNames.size();
+    iconThemeList->setColumnCount(iconNamesN + 2);
+
+    QList<QTreeWidgetItem *> items;
+    foreach (const QString &baseDirName, baseDirs)
     {
         QDir baseDir(baseDirName);
         if (!baseDir.exists())
             continue;
 
-        QFileInfoList dirs = baseDir.entryInfoList(QDir::AllDirs | QDir::NoDotAndDotDot, QDir::Name);
-        foreach (QFileInfo dir, dirs)
+        const QFileInfoList dirs = baseDir.entryInfoList(QDir::AllDirs | QDir::NoDotAndDotDot, QDir::Name);
+        foreach (const QFileInfo &dir, dirs)
         {
             if (!processed.contains(dir.canonicalFilePath()))
             {
@@ -72,22 +75,37 @@ void IconThemeConfig::initIconsThemes()
                 IconThemeInfo theme(QDir(dir.canonicalFilePath()));
                 if (theme.isValid() && (!theme.isHidden()))
                 {
-                    QTreeWidgetItem *item = new QTreeWidgetItem(iconThemeList);
+                    QTreeWidgetItem *item = new QTreeWidgetItem((QTreeWidget*)0);
                     item->setSizeHint(0, QSize(42,42)); // make icons non-cropped
                     item->setData(0, Qt::UserRole, theme.name());
 
-                    item->setIcon(0, theme.icon("document-open"));
-                    item->setIcon(1, theme.icon("document-new"));
-                    item->setIcon(2, theme.icon("edit-undo"));
-                    item->setIcon(3, theme.icon("media-playback-start"));
+                    const QVector<QIcon> icons = theme.icons(iconNames);
 
-                    item->setText(4, theme.comment().isEmpty() ? theme.text() : theme.text() + " (" + theme.comment() + ")");
+                    const int K = icons.size();
+                    for (int i = 0; i < K; ++i)
+                    {
+                        item->setIcon(i, icons.at(i));
+                    }
+
+                    QString themeDescription;
+                    if (theme.comment().isEmpty())
+                    {
+                        themeDescription = theme.text();
+                    }
+                    else
+                    {
+                        themeDescription = theme.text() % QStringLiteral(" (") % theme.comment() % QStringLiteral(")");
+                    }
+
+                    item->setText(iconNamesN + 1, themeDescription);
+
+                    items.append(item);
                 }
             }
         }
     }
 
-    iconThemeList->setColumnCount(5);
+    iconThemeList->insertTopLevelItems(0, items);
     for (int i=0; i<iconThemeList->header()->count()-1; ++i)
     {
         iconThemeList->resizeColumnToContents(i);
@@ -97,8 +115,7 @@ void IconThemeConfig::initIconsThemes()
 
 void IconThemeConfig::initControls()
 {
-    QString currentTheme = LxQt::Settings::globalSettings()->value("icon_theme").toString();
-    XdgIcon::setThemeName(currentTheme);
+    QString currentTheme = QIcon::themeName();
     QTreeWidgetItemIterator it(iconThemeList);
     while (*it) {
         if ((*it)->data(0, Qt::UserRole).toString() == currentTheme)
@@ -121,13 +138,13 @@ IconThemeConfig::~IconThemeConfig()
 void IconThemeConfig::iconThemeSelected(QTreeWidgetItem *item, int column)
 {
     Q_UNUSED(column);
-    QString theme = item->data(0, Qt::UserRole).toString();
+    const QString theme = item->data(0, Qt::UserRole).toString();
     if (!theme.isEmpty())
     {
-        XdgIcon::setThemeName(theme);
+        // Ensure that this widget also updates it's own icons
+        QIcon::setThemeName(theme);
+
         m_settings->setValue("icon_theme",  theme);
         m_settings->sync();
     }
 }
-
-
